Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1682)

Unified Diff: content/shell/android/shell_jni_registrar.h

Issue 12047068: Add apk for running content_browsertests (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Addressed comments Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/shell/android/shell_jni_registrar.h
diff --git a/content/app/android/app_jni_registrar.h b/content/shell/android/shell_jni_registrar.h
similarity index 52%
copy from content/app/android/app_jni_registrar.h
copy to content/shell/android/shell_jni_registrar.h
index 4b186a6ccfd0c68001eaccad829cfa8d4cf8cb8a..f336c525519dedb6752439e1d35daeb5f7be9c9b 100644
--- a/content/app/android/app_jni_registrar.h
+++ b/content/shell/android/shell_jni_registrar.h
@@ -2,18 +2,18 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CONTENT_APP_ANDROID_APP_JNI_REGISTRAR_H_
-#define CONTENT_APP_ANDROID_APP_JNI_REGISTRAR_H_
+#ifndef CONTENT_SHELL_ANDROID_SHELL_JNI_REGISTRAR_H_
+#define CONTENT_SHELL_ANDROID_SHELL_JNI_REGISTRAR_H_
#include <jni.h>
namespace content {
namespace android {
-// Register all JNI bindings necessary for content app.
-bool RegisterAppJni(JNIEnv* env);
+// Register all JNI bindings necessary for content shell.
+bool RegisterShellJni(JNIEnv* env);
} // namespace android
} // namespace content
-#endif // CONTENT_APP_ANDROID_APP_JNI_REGISTRAR_H_
+#endif // CONTENT_SHELL_ANDROID_SHELL_JNI_REGISTRAR_H_

Powered by Google App Engine
This is Rietveld 408576698